@@ -51,6 +51,7 @@ class SpeechGPT:
                         
         else:
             while True:
+                print("hi")
                 try:
                     with speech_recognition.Microphone() as mic:
                         blockPrint()
@@ -58,12 +59,17 @@ class SpeechGPT:
                         audio = self.recognizer.listen(mic)
                         audio_text = self.recognizer.recognize_google(audio).lower()
                         enablePrint()
-                        
+                        print(type(audio))
+                    
+                    
+                    if audio_text == 'quit':
+                        return    
                                 
                     if audio_text == str(self.wake_word).lower():
                         print("Waking up...")
                         self.listen(awake=True)
                         return
+                    
                         
                 except speech_recognition.UnknownValueError:
                     self.recognizer = speech_recognition.Recognizer()
